jamtorch.nn package
===================

Submodules
----------

jamtorch.nn.base\_modules module
--------------------------------

.. automodule:: jamtorch.nn.base_modules
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.nn.seq module
----------------------

.. automodule:: jamtorch.nn.seq
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.nn.simple\_network module
----------------------------------

.. automodule:: jamtorch.nn.simple_network
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jamtorch.nn
   :members:
   :undoc-members:
   :show-inheritance:
